aboutsummaryrefslogtreecommitdiff
path: root/test/functional/legacy/edit_spec.lua
diff options
context:
space:
mode:
Diffstat (limited to 'test/functional/legacy/edit_spec.lua')
-rw-r--r--test/functional/legacy/edit_spec.lua67
1 files changed, 27 insertions, 40 deletions
diff --git a/test/functional/legacy/edit_spec.lua b/test/functional/legacy/edit_spec.lua
index 0762e5e671..f3d18a2541 100644
--- a/test/functional/legacy/edit_spec.lua
+++ b/test/functional/legacy/edit_spec.lua
@@ -1,9 +1,10 @@
-local helpers = require('test.functional.helpers')(after_each)
+local n = require('test.functional.testnvim')()
local Screen = require('test.functional.ui.screen')
-local clear = helpers.clear
-local command = helpers.command
-local expect = helpers.expect
-local feed = helpers.feed
+
+local clear = n.clear
+local command = n.command
+local expect = n.expect
+local feed = n.feed
local sleep = vim.uv.sleep
before_each(clear)
@@ -30,22 +31,17 @@ describe('edit', function()
-- oldtest: Test_edit_insert_reg()
it('inserting a register using CTRL-R', function()
local screen = Screen.new(10, 6)
- screen:set_default_attr_ids({
- [0] = { bold = true, foreground = Screen.colors.Blue }, -- NonText
- [1] = { foreground = Screen.colors.Blue }, -- SpecialKey
- [2] = { bold = true }, -- ModeMsg
- })
screen:attach()
feed('a<C-R>')
screen:expect([[
- {1:^"} |
- {0:~ }|*4
- {2:-- INSERT --}|
+ {18:^"} |
+ {1:~ }|*4
+ {5:-- INSERT --}|
]])
feed('=')
screen:expect([[
- {1:"} |
- {0:~ }|*4
+ {18:"} |
+ {1:~ }|*4
=^ |
]])
end)
@@ -53,51 +49,42 @@ describe('edit', function()
-- oldtest: Test_edit_ctrl_r_failed()
it('positioning cursor after CTRL-R expression failed', function()
local screen = Screen.new(60, 6)
- screen:set_default_attr_ids({
- [0] = { bold = true, foreground = Screen.colors.Blue }, -- NonText
- [1] = { foreground = Screen.colors.Blue }, -- SpecialKey
- [2] = { foreground = Screen.colors.SlateBlue },
- [3] = { bold = true }, -- ModeMsg
- [4] = { reverse = true, bold = true }, -- MsgSeparator
- [5] = { background = Screen.colors.Red, foreground = Screen.colors.White }, -- ErrorMsg
- [6] = { foreground = Screen.colors.SeaGreen, bold = true }, -- MoreMsg
- })
screen:attach()
feed('i<C-R>')
screen:expect([[
- {1:^"} |
- {0:~ }|*4
- {3:-- INSERT --} |
+ {18:^"} |
+ {1:~ }|*4
+ {5:-- INSERT --} |
]])
- feed('={}')
+ feed('=0z')
screen:expect([[
- {1:"} |
- {0:~ }|*4
- ={2:{}}^ |
+ {18:"} |
+ {1:~ }|*4
+ ={26:0}{9:z}^ |
]])
- -- trying to insert a dictionary produces an error
+ -- trying to insert a blob produces an error
feed('<CR>')
screen:expect([[
- {1:"} |
- {0:~ }|
- {4: }|
- ={2:{}} |
- {5:E731: Using a Dictionary as a String} |
+ {18:"} |
+ {1:~ }|
+ {3: }|
+ ={26:0}{9:z} |
+ {9:E976: Using a Blob as a String} |
{6:Press ENTER or type command to continue}^ |
]])
feed(':')
screen:expect([[
:^ |
- {0:~ }|*4
- {3:-- INSERT --} |
+ {1:~ }|*4
+ {5:-- INSERT --} |
]])
-- ending Insert mode should put the cursor back on the ':'
feed('<Esc>')
screen:expect([[
^: |
- {0:~ }|*4
+ {1:~ }|*4
|
]])
end)